@@ -1,60 +1,62 @@
-from typing import List
-from policyengine_core.data import PrivateDataset, Dataset
-import h5py
-import logging
+from policyengine_core.data import Dataset
 import pandas as pd
 from pandas import DataFrame
+from ..utils import (
+    sum_to_entity,
+    categorical,
+    sum_from_positive_fields,
+    sum_positive_variables,
+    fill_with_mean,
+    STORAGE_FOLDER,
+)
+from typing import Dict, List
 import numpy as np
-from policyengine_uk.data.datasets.frs.raw_frs import RawFRS
-from policyengine_uk.data.storage import policyengine_uk_MICRODATA_FOLDER
-
-max_ = np.maximum
-where = np.where
+from numpy import maximum as max_, where
+from typing import Type
+import h5py
+from pathlib import Path
+from .raw_frs import (
+    RawFRS_2019_20,
+    RawFRS_2018_19,
+    RawFRS_2020_21,
+    RawFRS,
+    RawFRS_2021_22,
+    RawFRS_2022_23,
+)
 
 
-class FRS(PrivateDataset):
+class FRS(Dataset):
     name = "frs"
-    label = "FRS"
-    folder_path = policyengine_uk_MICRODATA_FOLDER
-    is_openfisca_compatible = True
+    label = "Family Resources Survey"
     data_format = Dataset.ARRAYS
+    raw_frs: Type[RawFRS] = None
 
-    filename_by_year = {
-        2019: "frs_2019.h5",
-    }
+    @staticmethod
+    def from_dataset(
+        raw_frs_type: Type[RawFRS],
+        new_name: str = None,
+        new_label: str = None,
+        new_url: str = None,
+    ):
+        class FRSFromRawFRS(FRS):
+            name = new_name
+            label = new_label
+            raw_frs = raw_frs_type
+            time_period = raw_frs_type.time_period
+            file_path = STORAGE_FOLDER / f"{new_name}.h5"
+            url = new_url
 
-    def generate(self, year: int):
-        if year in self.years:
-            self.remove(year)
-        # Load raw FRS tables
-        year = int(year)
+        return FRSFromRawFRS
 
-        if len(RawFRS.years) == 0:
+    def generate(self):
+        raw_frs_files = self.raw_frs()
+        if not raw_frs_files.file_path.exists():
             raise FileNotFoundError(
-                "Raw FRS not found. Please run `openfisca-uk data raw_frs generate [year]` first."
+                f"Raw FRS file {raw_frs_files.file_path} not found."
             )
-
-        if year > max(RawFRS.years):
-            logging.warning("Uprating a previous version of the FRS.")
-            if len(self.years) == 0:
-                self.generate(max(RawFRS.years))
-            if len(FRS.years) > 0:
-                frs_year = max(self.years)
-                from policyengine_uk import Microsimulation
-
-                sim = Microsimulation(
-                    dataset=self, dataset_year=max(self.years)
-                )
-                frs = h5py.File(self.file(year), mode="w")
-                for variable in self.keys(frs_year):
-                    frs[variable] = sim.calc(variable).values
-                frs.close()
-                return
-
-        raw_frs_files = RawFRS.load(year)
-        frs = h5py.File(self.file(year), mode="w")
-        logging.info("Generating FRS dataset for year {}".format(year))
-        logging.info("Loading FRS tables")
+        else:
+            raw_frs_files = raw_frs_files.load()
+        frs = h5py.File(self.file_path, mode="w")
         TABLES = (
             "adult",
             "child",
@@ -87,18 +89,13 @@ class FRS(PrivateDataset):
         ) = [raw_frs_files[table] for table in TABLES]
         raw_frs_files.close()
 
-        logging.info("Joining adult and child tables")
-
         person = pd.concat([adult, child]).sort_index().fillna(0)
-
-        # Generate OpenFisca-UK variables and save
-        logging.info("Generating OpenFisca-UK variables")
         add_id_variables(frs, person, benunit, household)
-        add_personal_variables(frs, person)
+        add_personal_variables(frs, person, self.raw_frs.time_period)
         add_benunit_variables(frs, benunit)
-        add_household_variables(frs, household)
+        add_household_variables(frs, household, self.raw_frs.time_period)
         add_market_income(
-            frs, person, pension, job, accounts, household, oddjob, year
+            frs, person, pension, job, accounts, household, oddjob
         )
         add_benefit_income(frs, person, benefits, household)
         add_expenses(
@@ -112,10 +109,38 @@ class FRS(PrivateDataset):
             pen_prov,
         )
         frs.close()
-        logging.info("Completed FRS generation")
 
 
-FRS = FRS()
+FRS_2018_19 = FRS.from_dataset(
+    RawFRS_2018_19,
+    "frs_2018",
+    "FRS 2018-19",
+)
+
+FRS_2019_20 = FRS.from_dataset(
+    RawFRS_2019_20,
+    "frs_2019",
+    "FRS 2019-20",
+)
+
+FRS_2020_21 = FRS.from_dataset(
+    RawFRS_2020_21,
+    "frs_2020",
+    "FRS 2020-21",
+)
+
+FRS_2021_22 = FRS.from_dataset(
+    RawFRS_2021_22,
+    "frs_2021",
+    "FRS 2021-22",
+)
+
+FRS_2022_23 = FRS.from_dataset(
+    RawFRS_2022_23,
+    "frs_2022",
+    "FRS 2022-23",
+    new_url="release://policyengine/non-public-microdata/uk-2024-july/raw_frs_2022.h5",
+)
 
 
 def sum_to_entity(
@@ -177,7 +202,7 @@ def add_id_variables(
     frs["household_weight"] = household.GROSS4
 
 
-def add_personal_variables(frs: h5py.File, person: DataFrame):
+def add_personal_variables(frs: h5py.File, person: DataFrame, year: int):
     """Adds personal variables (age, gender, education).
 
     Args:
@@ -187,13 +212,14 @@ def add_personal_variables(frs: h5py.File, person: DataFrame):
     # Add basic personal variables
     age = person.AGE80 + person.AGE
     frs["age"] = age
+    frs["birth_year"] = np.ones_like(person.AGE) * (year - age)
     # Age fields are AGE80 (top-coded) and AGE in the adult and child tables, respectively.
     frs["state_id"] = np.array([1])
     frs["person_state_id"] = np.array([1] * len(person))
     frs["person_state_role"] = np.array(["member"] * len(person)).astype("S")
     frs["state_weight"] = np.array([1])
     frs["gender"] = np.where(person.SEX == 1, "MALE", "FEMALE").astype("S")
-    frs["hours_worked"] = person.TOTHOURS * 52
+    frs["hours_worked"] = np.maximum(person.TOTHOURS, 0) * 52
     frs["is_household_head"] = person.HRPID == 1
     frs["is_benunit_head"] = person.UPERSON == 1
     MARITAL = [
@@ -209,7 +235,10 @@ def add_personal_variables(frs: h5py.File, person: DataFrame):
     )
 
     # Add education levels
-    fted = person.FTED
+    if "FTED" in person.columns:
+        fted = person.FTED
+    else:
+        fted = person.EDUCFT  # Renamed in FRS 2022-23
     typeed2 = person.TYPEED2
     frs["current_education"] = np.select(
         [
@@ -274,7 +303,7 @@ def add_personal_variables(frs: h5py.File, person: DataFrame):
     )
 
 
-def add_household_variables(frs: h5py.File, household: DataFrame):
+def add_household_variables(frs: h5py.File, household: DataFrame, year: int):
     """Adds household variables (region, tenure, council tax imputation).
 
     Args:
@@ -377,15 +406,19 @@ def add_household_variables(frs: h5py.File, household: DataFrame):
         household.CTBAND, 1, range(1, 10), BANDS
     )
     # Domestic rates variables are all weeklyised, unlike Council Tax variables (despite the variable name suggesting otherwise)
+    if year < 2021:
+        DOMESTIC_RATES_VARIABLE = "RTANNUAL"
+    else:
+        DOMESTIC_RATES_VARIABLE = "NIRATLIA"
     frs["domestic_rates"] = (
         np.select(
             [
-                household.RTANNUAL >= 0,
+                household[DOMESTIC_RATES_VARIABLE] >= 0,
                 household.RT2REBAM >= 0,
                 True,
             ],
             [
-                household.RTANNUAL,
+                household[DOMESTIC_RATES_VARIABLE],
                 household.RT2REBAM,
                 0,
             ],
@@ -402,7 +435,6 @@ def add_market_income(
     account: DataFrame,
     household: DataFrame,
     oddjob: DataFrame,
-    year: DataFrame,
 ):
     """Adds income variables (non-benefit).
 
@@ -414,7 +446,6 @@ def add_market_income(
         account (DataFrame)
         household (DataFrame)
         oddjob (DataFrame)
-        year (DataFrame)
     """
     frs["employment_income"] = person.INEARNS * 52
 
@@ -436,21 +467,11 @@ def add_market_income(
         person.index,
     )
 
-    frs["pension_income"] = (
+    frs["private_pension_income"] = (
         pension_payment + pension_tax_paid + pension_deductions_removed
     ) * 52
 
-    # Add self-employed income (correcting one person in 2018)
-    INCORRECT_VALUES_PERSON_ID = 806911
-    seincamt = sum_to_entity(job.SEINCAMT, job.person_id, person.index)
-    frs["self_employment_income"] = (
-        np.where(
-            (year == 2018) & (person.index == INCORRECT_VALUES_PERSON_ID),
-            seincamt,
-            person.SEINCAM2,
-        )
-        * 52
-    )
+    frs["self_employment_income"] = person.SEINCAM2 * 52
 
     INVERTED_BASIC_RATE = 1.25
 
@@ -528,13 +549,7 @@ def add_market_income(
         ).fillna(0),
         0,
     )
-    use_DWP_usual_amount = (person.MNTUS2 == 2) & ~(
-        (year == 2018)
-        & (person.household_id.isin(INVERTED_USUAL_AMOUNT_HOUSEHOLDS))
-    )
-    maintenance_from_DWP = pd.Series(
-        where(use_DWP_usual_amount, person.MNTUSAM2, person.MNTAMT2)
-    )
+    maintenance_from_DWP = person.MNTAMT2
     frs["maintenance_income"] = (
         sum_positive_variables([maintenance_to_self, maintenance_from_DWP])
         * 52
@@ -725,11 +740,13 @@ def add_benefit_income(
         np.array(frs["winter_fuel_allowance_reported"]) / 52
     )
 
-    frs["SSP"] = person.SSPADJ * 52
-    frs["SMP"] = person.SMPADJ * 52
+    frs["statutory_sick_pay"] = person.SSPADJ * 52
+    frs["statutory_maternity_pay"] = person.SMPADJ * 52
 
     frs["student_loans"] = np.maximum(person.TUBORR, 0)
-
+    if "ADEMA" not in person.columns:
+        person["ADEMA"] = person.EDUMA
+        person["ADEMAAMT"] = person.EDUMAAMT
     frs["adult_ema"] = fill_with_mean(person, "ADEMA", "ADEMAAMT")
     frs["child_ema"] = fill_with_mean(person, "CHEMA", "CHEMAAMT")
 
