@@ -6,14 +6,14 @@ from itertools import product
 UPRATED_VARIABLES = (
     "council_tax",
     "employment_income",
-    "pension_income",
+    "private_pension_income",
     "self_employment_income",
     "property_income",
     "savings_interest_income",
     "dividend_income",
 )
 
-sim = Microsimulation(dataset=EnhancedFRS, dataset_year=2022)
+sim = Microsimulation(dataset=EnhancedFRS)
 
 
 @pytest.mark.parametrize(
