@@ -28,13 +28,13 @@ class tax_credits_applicable_income(Variable):
     def formula(benunit, period, parameters):
         TC = parameters(period).gov.dwp.tax_credits
         STEP_1_COMPONENTS = [
-            "pension_income",
+            "private_pension_income",
             "savings_interest_income",
             "dividend_income",
             "property_income",
         ]
-        income = aggr(benunit, period, STEP_1_COMPONENTS)
-        income = amount_over(income, TC.means_test.non_earned_disregard)
+        income = add(benunit, period, STEP_1_COMPONENTS)
+        income = max_(income - TC.means_test.non_earned_disregard, 0)
         STEP_2_COMPONENTS = [
             "employment_income",
             "self_employment_income",
@@ -44,7 +44,7 @@ class tax_credits_applicable_income(Variable):
         bi = parameters(period).gov.contrib.ubi_center.basic_income
         if bi.interactions.include_in_means_tests:
             STEP_2_COMPONENTS.append("basic_income")
-        income += aggr(benunit, period, STEP_2_COMPONENTS)
+        income += add(benunit, period, STEP_2_COMPONENTS)
         EXEMPT_BENEFITS = ["income_support", "ESA_income", "JSA_income"]
         on_exempt_benefits = add(benunit, period, EXEMPT_BENEFITS) > 0
         return income * ~on_exempt_benefits
@@ -86,7 +86,7 @@ class is_CTC_eligible(Variable):
 
     def formula(benunit, period, parameters):
         already_claiming = (
-            aggr(benunit, period, ["child_tax_credit_reported"]) > 0
+            add(benunit, period, ["child_tax_credit_reported"]) > 0
         )
         return (
             benunit.any(benunit.members("is_child_for_CTC", period))
@@ -104,24 +104,20 @@ class would_claim_CTC(Variable):
     definition_period = YEAR
 
     def formula(benunit, period, parameters):
-        reported_ctc = aggr(benunit, period, ["child_tax_credit_reported"]) > 0
+        reported_ctc = add(benunit, period, ["child_tax_credit_reported"]) > 0
         claims_all_entitled_benefits = benunit(
             "claims_all_entitled_benefits", period
         )
         baseline = benunit("baseline_ctc_entitlement", period) > 0
-        eligible = benunit("ctc_entitlement", period) > 0
         takeup_rate = parameters(period).gov.dwp.housing_benefit.takeup
+        claims_legacy_benefits = benunit("claims_legacy_benefits", period)
         return select(
             [
                 reported_ctc | claims_all_entitled_benefits,
-                ~baseline & eligible,
-                True,
-            ],
-            [
-                True,
-                random(benunit) < takeup_rate,
-                False,
+                ~baseline & claims_legacy_benefits,
             ],
+            [True, random(benunit) < takeup_rate],
+            default=False,
         )
 
 
@@ -133,14 +129,12 @@ class CTC_maximum_rate(Variable):
     reference = "Tax Credits Act 2002 s. 9"
     unit = GBP
 
-    def formula(benunit, period, parameters):
-        ELEMENTS = [
-            "CTC_family_element",
-            "CTC_child_element",
-            "CTC_disabled_child_element",
-            "CTC_severely_disabled_child_element",
-        ]
-        return add(benunit, period, ELEMENTS)
+    adds = [
+        "CTC_family_element",
+        "CTC_child_element",
+        "CTC_disabled_child_element",
+        "CTC_severely_disabled_child_element",
+    ]
 
 
 class CTC_family_element(Variable):
@@ -150,10 +144,12 @@ class CTC_family_element(Variable):
     definition_period = YEAR
     reference = "Tax Credits Act 2002 s. 9"
     unit = GBP
+    defined_for = "is_CTC_eligible"
 
     def formula(benunit, period, parameters):
-        CTC = parameters(period).gov.dwp.tax_credits.child_tax_credit
-        return benunit("is_CTC_eligible", period) * CTC.elements.family_element
+        return parameters(
+            period
+        ).gov.dwp.tax_credits.child_tax_credit.elements.family_element
 
 
 class CTC_child_element(Variable):
@@ -173,10 +169,35 @@ class CTC_child_element(Variable):
         exempt_children = benunit.sum(exempt_child)
         child_limit = CTC.limit.child_count
         spaces_left = max_(0, child_limit - exempt_children)
-        non_exempt_children = min_(spaces_left, benunit.sum(is_child_for_CTC))
+        non_exempt_children = min_(
+            spaces_left, benunit.sum(is_child_for_CTC) - exempt_children
+        )
         children = exempt_children + non_exempt_children
-        amount = CTC.elements.child_element * children
-        return amount
+        return CTC.elements.child_element * children
+
+
+class ctc_child_limit_affected(Variable):
+    label = "affected by the CTC child limit"
+    entity = BenUnit
+    definition_period = YEAR
+    value_type = bool
+
+    def formula(benunit, period, parameters):
+        person = benunit.members
+        CTC = parameters(period).gov.dwp.tax_credits.child_tax_credit
+        is_child_for_CTC = person("is_child_for_CTC", period)
+        is_CTC_child_limit_exempt = person("is_CTC_child_limit_exempt", period)
+        exempt_child = is_child_for_CTC & is_CTC_child_limit_exempt
+        exempt_children = benunit.sum(exempt_child)
+        child_limit = CTC.limit.child_count
+        spaces_left = max_(0, child_limit - exempt_children)
+        non_exempt_children = min_(
+            spaces_left, benunit.sum(is_child_for_CTC) - exempt_children
+        )
+        return (
+            exempt_children + non_exempt_children
+            < benunit.sum(is_child_for_CTC)
+        ) & (benunit("child_tax_credit", period) > 0)
 
 
 class CTC_disabled_child_element(Variable):
@@ -205,6 +226,7 @@ class CTC_severely_disabled_child_element(Variable):
     definition_period = YEAR
     reference = "Tax Credits Act 2002 s. 9"
     unit = GBP
+    defined_for = "is_CTC_eligible"
 
     def formula(benunit, period, parameters):
         person = benunit.members
@@ -217,10 +239,9 @@ class CTC_severely_disabled_child_element(Variable):
         )
         severely_disabled_children = benunit.sum(is_severely_disabled_child)
         CTC = parameters(period).gov.dwp.tax_credits.child_tax_credit
-        amount = (
+        return (
             CTC.elements.severe_dis_child_element * severely_disabled_children
         )
-        return benunit("is_CTC_eligible", period) * amount
 
 
 class is_WTC_eligible(Variable):
@@ -258,7 +279,7 @@ class is_WTC_eligible(Variable):
         meets_medium = meets_medium_total_hours & meets_medium_person_hours
         meets_higher = total_hours >= WTC.min_hours.default
         already_claiming = (
-            aggr(benunit, period, ["working_tax_credit_reported"]) > 0
+            add(benunit, period, ["working_tax_credit_reported"]) > 0
         )
         return (
             (lower_req & meets_lower)
@@ -278,25 +299,21 @@ class would_claim_WTC(Variable):
 
     def formula(benunit, period, parameters):
         reported_wtc = (
-            aggr(benunit, period, ["working_tax_credit_reported"]) > 0
+            add(benunit, period, ["working_tax_credit_reported"]) > 0
         )
         claims_all_entitled_benefits = benunit(
             "claims_all_entitled_benefits", period
         )
         baseline = benunit("baseline_wtc_entitlement", period) > 0
-        eligible = benunit("wtc_entitlement", period) > 0
         takeup_rate = parameters(period).gov.dwp.housing_benefit.takeup
+        claims_legacy_benefits = benunit("claims_legacy_benefits", period)
         return select(
             [
                 reported_wtc | claims_all_entitled_benefits,
-                ~baseline & eligible,
-                True,
-            ],
-            [
-                True,
-                random(benunit) < takeup_rate,
-                False,
+                ~baseline & claims_legacy_benefits,
             ],
+            [True, random(benunit) < takeup_rate],
+            default=False,
         )
 
 
@@ -308,17 +325,15 @@ class WTC_maximum_rate(Variable):
     reference = "Tax Credits Act 2002 s. 11"
     unit = GBP
 
-    def formula(benunit, period, parameters):
-        ELEMENTS = [
-            "WTC_basic_element",
-            "WTC_couple_element",
-            "WTC_lone_parent_element",
-            "WTC_disabled_element",
-            "WTC_severely_disabled_element",
-            "WTC_worker_element",
-            "WTC_childcare_element",
-        ]
-        return add(benunit, period, ELEMENTS)
+    adds = [
+        "WTC_basic_element",
+        "WTC_couple_element",
+        "WTC_lone_parent_element",
+        "WTC_disabled_element",
+        "WTC_severely_disabled_element",
+        "WTC_worker_element",
+        "WTC_childcare_element",
+    ]
 
 
 class WTC_basic_element(Variable):
@@ -328,10 +343,12 @@ class WTC_basic_element(Variable):
     definition_period = YEAR
     reference = "Tax Credits Act 2002 s. 11"
     unit = GBP
+    defined_for = "is_WTC_eligible"
 
     def formula(benunit, period, parameters):
-        WTC = parameters(period).gov.dwp.tax_credits.working_tax_credit
-        return benunit("is_WTC_eligible", period) * WTC.elements.basic
+        return parameters(
+            period
+        ).gov.dwp.tax_credits.working_tax_credit.elements.basic
 
 
 class WTC_couple_element(Variable):
@@ -341,13 +358,13 @@ class WTC_couple_element(Variable):
     definition_period = YEAR
     reference = "Tax Credits Act 2002 s. 11"
     unit = GBP
+    defined_for = "is_WTC_eligible"
 
     def formula(benunit, period, parameters):
         WTC = parameters(period).gov.dwp.tax_credits.working_tax_credit
         relation_type = benunit("relation_type", period)
         relations = relation_type.possible_values
-        amount = (relation_type == relations.COUPLE) * WTC.elements.couple
-        return benunit("is_WTC_eligible", period) * amount
+        return (relation_type == relations.COUPLE) * WTC.elements.couple
 
 
 class WTC_lone_parent_element(Variable):
@@ -357,17 +374,14 @@ class WTC_lone_parent_element(Variable):
     definition_period = YEAR
     reference = "Tax Credits Act 2002 s. 11"
     unit = GBP
+    defined_for = "is_WTC_eligible"
 
     def formula(benunit, period, parameters):
         WTC = parameters(period).gov.dwp.tax_credits.working_tax_credit
         family_type = benunit("family_type", period)
         families = family_type.possible_values
         lone_parent = family_type == families.LONE_PARENT
-        return (
-            benunit("is_WTC_eligible", period)
-            * lone_parent
-            * WTC.elements.lone_parent
-        )
+        return lone_parent * WTC.elements.lone_parent
 
 
 class WTC_disabled_element(Variable):
@@ -377,6 +391,7 @@ class WTC_disabled_element(Variable):
     definition_period = YEAR
     reference = "Tax Credits Act 2002 s. 11"
     unit = GBP
+    defined_for = "is_WTC_eligible"
 
     def formula(benunit, period, parameters):
         WTC = parameters(period).gov.dwp.tax_credits.working_tax_credit
@@ -390,11 +405,7 @@ class WTC_disabled_element(Variable):
             & person("is_adult", period)
         )
         qualifies = benunit.any(person_qualifies)
-        return (
-            benunit("is_WTC_eligible", period)
-            * qualifies
-            * WTC.elements.disabled
-        )
+        return qualifies * WTC.elements.disabled
 
 
 class WTC_severely_disabled_element(Variable):
@@ -421,16 +432,13 @@ class WTC_worker_element(Variable):
     definition_period = YEAR
     reference = "Tax Credits Act 2002 s. 11"
     unit = GBP
+    defined_for = "is_WTC_eligible"
 
     def formula(benunit, period, parameters):
         WTC = parameters(period).gov.dwp.tax_credits.working_tax_credit
-        hours = aggr(benunit, period, ["weekly_hours"])
+        hours = add(benunit, period, ["weekly_hours"])
         meets_hours_requirement = hours >= WTC.min_hours.default
-        return (
-            benunit("is_WTC_eligible", period)
-            * meets_hours_requirement
-            * WTC.elements.worker
-        )
+        return meets_hours_requirement * WTC.elements.worker
 
 
 class WTC_childcare_element(Variable):
@@ -440,6 +448,7 @@ class WTC_childcare_element(Variable):
     definition_period = YEAR
     reference = "Tax Credits Act 2002 s. 11"
     unit = GBP
+    defined_for = "is_WTC_eligible"
 
     def formula(benunit, period, parameters):
         WTC = parameters(period).gov.dwp.tax_credits.working_tax_credit
@@ -447,10 +456,9 @@ class WTC_childcare_element(Variable):
         childcare_1 = (num_children == 1) * WTC.elements.childcare_1
         childcare_2 = (num_children > 1) * WTC.elements.childcare_2
         max_childcare_amount = (childcare_1 + childcare_2) * WEEKS_IN_YEAR
-        expenses = aggr(benunit, period, ["childcare_expenses"])
+        expenses = add(benunit, period, ["childcare_expenses"])
         eligible_expenses = min_(max_childcare_amount, expenses)
-        childcare_element = WTC.elements.childcare_coverage * eligible_expenses
-        return benunit("is_WTC_eligible", period) * childcare_element
+        return WTC.elements.childcare_coverage * eligible_expenses
 
 
 class tax_credits_reduction(Variable):
@@ -482,6 +490,7 @@ class working_tax_credit_pre_minimum(Variable):
     documentation = (
         "Working Tax Credit amount before the minimum tax credit is applied"
     )
+    defined_for = "would_claim_WTC"
     definition_period = YEAR
     unit = GBP
 
@@ -500,6 +509,7 @@ class child_tax_credit_pre_minimum(Variable):
     documentation = (
         "Child Tax Credit amount before the minimum tax credit is applied"
     )
+    defined_for = "would_claim_CTC"
     definition_period = YEAR
     unit = GBP
 
@@ -538,7 +548,7 @@ class ctc_entitlement(Variable):
     entity = BenUnit
     definition_period = YEAR
     value_type = float
-    unit = "currency-GBP"
+    unit = GBP
 
     def formula(benunit, period, parameters):
         return where(
@@ -554,11 +564,8 @@ class child_tax_credit(Variable):
     label = "Child Tax Credit"
     definition_period = YEAR
     unit = GBP
-
-    def formula(benunit, period, parameters):
-        entitlement = benunit("ctc_entitlement", period)
-        would_claim = benunit("would_claim_CTC", period)
-        return entitlement * would_claim
+    defined_for = "would_claim_CTC"
+    adds = ["ctc_entitlement"]
 
 
 class wtc_entitlement(Variable):
@@ -566,14 +573,15 @@ class wtc_entitlement(Variable):
     entity = BenUnit
     definition_period = YEAR
     value_type = float
-    unit = "currency-GBP"
+    unit = GBP
+    defined_for = "is_WTC_eligible"
 
     def formula(benunit, period, parameters):
         return where(
             benunit("tax_credits", period) > 0,
             benunit("working_tax_credit_pre_minimum", period),
             0,
-        ) * (benunit("is_WTC_eligible", period))
+        )
 
 
 class working_tax_credit(Variable):
@@ -582,11 +590,8 @@ class working_tax_credit(Variable):
     label = "Working Tax Credit"
     definition_period = YEAR
     unit = GBP
-
-    def formula(benunit, period, parameters):
-        entitlement = benunit("wtc_entitlement", period)
-        would_claim = benunit("would_claim_WTC", period)
-        return entitlement * would_claim
+    defined_for = "would_claim_WTC"
+    adds = ["wtc_entitlement"]
 
 
 class baseline_wtc_entitlement(Variable):
@@ -595,9 +600,21 @@ class baseline_wtc_entitlement(Variable):
     definition_period = YEAR
     value_type = float
 
+    def formula(benunit, period, parameters):
+        if benunit.simulation.baseline is None:
+            return 1
+        baseline = benunit.simulation.baseline.populations["benunit"]
+        return baseline("wtc_entitlement", period)
+
 
 class baseline_ctc_entitlement(Variable):
     label = "Receives Child Tax Credit (baseline)"
     entity = BenUnit
     definition_period = YEAR
     value_type = float
+
+    def formula(benunit, period, parameters):
+        if benunit.simulation.baseline is None:
+            return 1
+        baseline = benunit.simulation.baseline.populations["benunit"]
+        return baseline("wtc_entitlement", period)
