@@ -20,52 +20,67 @@ class would_claim_child_benefit(Variable):
     value_type = bool
 
     def formula(benunit, period, parameters):
-        claims_benefits = benunit("claims_all_entitled_benefits", period)
-        already_claiming = (
-            aggr(benunit, period, ["child_benefit_reported"]) > 0
-        )
         takeup_rate = parameters(period).gov.hmrc.child_benefit.takeup
-        baseline_cb = benunit("baseline_child_benefit_entitlement", period) > 0
-        eligible = benunit("child_benefit_entitlement", period) > 0
-        return select(
-            [
-                already_claiming | claims_benefits,
-                ~baseline_cb & eligible,
-                True,
-            ],
-            [
-                True,  # Claims Child Benefit in the baseline
-                random(benunit)
-                < takeup_rate,  # New CB eligibility from a reform
-                False,  # Always non-claimant
-            ],
+        overall_p = takeup_rate.overall
+        return (random(benunit) < overall_p) * ~benunit(
+            "child_benefit_opts_out", period
         )
 
 
+class child_benefit_opts_out(Variable):
+    label = "opts out of Child Benefit"
+    documentation = (
+        "Whether this family would opt out of receiving Child Benefit payments"
+    )
+    entity = BenUnit
+    definition_period = YEAR
+    value_type = bool
+
+    def formula(benunit, period, parameters):
+        if hasattr(benunit.simulation, "dataset"):
+            ani = benunit.members("adjusted_net_income", period)
+            hmrc = parameters(period).gov.hmrc
+            cb_hitc = hmrc.income_tax.charges.CB_HITC
+            cb = hmrc.child_benefit
+            in_phase_out = ani > cb_hitc.phase_out_end
+            return where(
+                benunit.any(in_phase_out),
+                random(benunit) < cb.opt_out_rate,
+                False,
+            )
+        else:
+            # If we're not in a microsimulation, assume the family would not opt out
+            return False
+
+
 class child_benefit_respective_amount(Variable):
     label = "Child Benefit (respective amount)"
     documentation = "The amount of this benefit unit's Child Benefit which is in respect of this person"
     entity = Person
-    definition_period = YEAR
+    definition_period = MONTH
     value_type = float
     unit = GBP
     reference = (
         "https://www.legislation.gov.uk/ukpga/1992/4/part/IX",
         "https://www.legislation.gov.uk/uksi/2006/965/regulation/2",
     )
+    defined_for = "is_child_or_QYP"
 
     def formula(person, period, parameters):
-        eligible = person("is_child_or_QYP", period)
+        eligible = True
         if parameters(
             period
         ).gov.contrib.ubi_center.basic_income.interactions.withdraw_cb:
-            eligible &= person("basic_income", period) == 0
-        is_eldest = person("is_eldest_child", period)
+            eligible &= (
+                person.benunit.sum(person("basic_income", period.this_year))
+                == 0
+            )
+        is_eldest = person("is_eldest_child", period.this_year)
         child_benefit = parameters(period).gov.hmrc.child_benefit.amount
         amount = where(
             is_eldest, child_benefit.eldest, child_benefit.additional
         )
-        return eligible * amount * WEEKS_IN_YEAR
+        return eligible * amount * WEEKS_IN_YEAR / MONTHS_IN_YEAR
 
 
 class child_benefit_entitlement(Variable):
@@ -75,7 +90,7 @@ class child_benefit_entitlement(Variable):
     value_type = float
     unit = GBP
 
-    formula = sum_of_variables(["child_benefit_respective_amount"])
+    adds = ["child_benefit_respective_amount"]
 
 
 class child_benefit(Variable):
@@ -86,11 +101,8 @@ class child_benefit(Variable):
     value_type = float
     unit = GBP
     category = BENEFIT
-
-    def formula(benunit, period):
-        entitlement = benunit("child_benefit_entitlement", period)
-        would_claim = benunit("would_claim_child_benefit", period)
-        return would_claim * entitlement
+    defined_for = "would_claim_child_benefit"
+    adds = ["child_benefit_entitlement"]
 
 
 class child_benefit_less_tax_charge(Variable):
@@ -103,10 +115,8 @@ class child_benefit_less_tax_charge(Variable):
     value_type = float
     unit = GBP
 
-    def formula(benunit, period):
-        benefit = benunit("child_benefit", period)
-        charge = benunit.sum(benunit.members("CB_HITC", period))
-        return benefit - charge
+    adds = ["child_benefit"]
+    subtracts = ["CB_HITC"]
 
 
 class baseline_child_benefit_entitlement(Variable):
