@@ -8,15 +8,13 @@ class tax(Variable):
     definition_period = YEAR
     unit = GBP
 
-    def formula(person, period, parameters):
-        TAXES = ["income_tax", "national_insurance"]
-        return add(person, period, TAXES)
+    adds = ["income_tax", "national_insurance"]
 
 
 class household_tax(Variable):
     value_type = float
     entity = Household
-    label = "taxes"
+    label = "household taxes"
     documentation = "Total taxes owed by the household"
     definition_period = YEAR
     unit = GBP
@@ -31,12 +29,30 @@ class household_tax(Variable):
         "change_in_fuel_duty",
         "tv_licence",
         "wealth_tax",
+        "non_primary_residence_wealth_tax",
         "income_tax",
         "national_insurance",
         "LVT",
         "carbon_tax",
+        "vat_change",
+        "capital_gains_tax",
+        "private_school_vat",
     ]
 
+    def formula(household, period, parameters):
+        if parameters(period).gov.contrib.abolish_council_tax:
+            return add(
+                household,
+                period,
+                [
+                    tax
+                    for tax in household_tax.adds
+                    if tax not in ["council_tax"]
+                ],
+            )
+        else:
+            return add(household, period, household_tax.adds)
+
 
 class benunit_tax(Variable):
     value_type = float
@@ -45,8 +61,7 @@ class benunit_tax(Variable):
     definition_period = YEAR
     unit = GBP
 
-    def formula(benunit, period, parameters):
-        return aggr(benunit, period, ["tax"])
+    adds = ["tax"]
 
 
 class tax_reported(Variable):
@@ -64,5 +79,5 @@ class tax_modelling(Variable):
     definition_period = YEAR
     unit = GBP
 
-    def formula(person, period, parameters):
-        return person("tax", period) - person("tax_reported", period)
+    adds = ["tax"]
+    subtracts = ["tax_reported"]
