@@ -1,5 +1,5 @@
 from policyengine_uk.model_api import *
-from policyengine_uk.variables.input.consumption.property.maintenance import (
+from policyengine_uk.variables.input.housing import (
     CouncilTaxBand,
 )
 
@@ -16,7 +16,6 @@ class ebr_council_tax_rebate(Variable):
         ctr = parameters(
             period
         ).gov.treasury.energy_bills_rebate.council_tax_rebate
-        ct_amount = household("council_tax", period)
         ct_band = household("council_tax_band", period)
         eligible = np.any(
             np.array(
