@@ -1,4 +1,4 @@
-from policyengine_uk.data.datasets import EnhancedFRS, SynthFRS
+from policyengine_uk.data.datasets import EnhancedFRS
 from policyengine_uk.model_api import *
 
 
@@ -124,6 +124,21 @@ class in_poverty_ahc(Variable):
         return income < (threshold * WEEKS_IN_YEAR)
 
 
+class in_relative_poverty_ahc(Variable):
+    label = "in relative poverty (AHC)"
+    entity = Household
+    definition_period = YEAR
+    value_type = bool
+
+    def formula(household, period, parameters):
+        income = household("equiv_hbai_household_net_income_ahc", period)
+        # Less than 60% of median income
+        median_income = MicroSeries(
+            income, weights=household("household_weight", period)
+        ).median()
+        return income < (median_income * 0.6)
+
+
 class in_deep_poverty_bhc(Variable):
     value_type = bool
     entity = Household
@@ -213,19 +228,6 @@ class baseline_hbai_excluded_income(Variable):
     def formula(household, period, parameters):
         if not parameters(period).household.poverty.exclude_non_hbai_income:
             return 0
-        # Establish if currently running a microsimulation
-        if len(household.nb_persons()) > 1_000:
-            from policyengine_uk import Microsimulation
-
-            # Simulate baseline policy
-            dataset = EnhancedFRS if 2022 in EnhancedFRS.years else SynthFRS
-            result = Microsimulation(
-                dataset=dataset, dataset_year=2022
-            ).calculate("hbai_excluded_income", period)
-            # Check that the dataset/year combination is valid
-            # (i.e. that the arrays are the same size)
-            if len(result) == len(household.nb_persons()):
-                return result
         # If baseline policy not viable from the above method,
         # no change in HBAI excluded income
         return household("hbai_excluded_income", period)
