@@ -10,6 +10,13 @@ class shareholding(Variable):
     unit = GBP
 
     def formula(household, period, parameters):
+        wealth = household("corporate_wealth", period)
+        if (
+            hasattr(household.simulation, "dataset")
+            and household("corporate_wealth", period).sum() != 0
+        ):
+            weight = household("household_weight", period)
+            return wealth / (wealth * weight).sum()
         wealth = parameters(period).household.wealth
         nbs = wealth.national_balance_sheet
         wealth = household("corporate_wealth", period)
@@ -27,9 +34,7 @@ class corporate_tax_incidence(Variable):
     value_type = float
     unit = GBP
 
-    def formula(household, period):
-        TAXES = [
-            "corporate_sdlt_change_incidence",
-            "business_rates_change_incidence",
-        ]
-        return add(household, period, TAXES)
+    adds = [
+        "corporate_sdlt_change_incidence",
+        "business_rates_change_incidence",
+    ]
