@@ -63,24 +63,3 @@ class council_tax(Variable):
     unit = GBP
     quantity_type = FLOW
     uprating: str = "calibration.uprating.council_tax"
-
-
-class CouncilTaxBand(Enum):
-    A = "A"
-    B = "B"
-    C = "C"
-    D = "D"
-    E = "E"
-    F = "F"
-    G = "G"
-    H = "H"
-    I = "I"
-
-
-class council_tax_band(Variable):
-    value_type = Enum
-    possible_values = CouncilTaxBand
-    default_value = CouncilTaxBand.D
-    entity = Household
-    label = "Council Tax band"
-    definition_period = YEAR
